@@ -1,11 +1,11 @@
 import flask_sqlalchemy
 
 from wedeliver_core import WeDeliverCore
-from wedeliver_core.wedeliver_core.helpers.exceptions import AppMicroFetcherError, AppFetchServiceDataError
+from wedeliver_core.helpers.exceptions import AppMicroFetcherError, AppFetchServiceDataError
 import requests
 import json
 
-from wedeliver_core.wedeliver_core.helpers.get_obj_value import get_obj_value
+from wedeliver_core.helpers.get_obj_value import get_obj_value
 
 
 class MicroFetcher(object):
